@@ -34,7 +34,6 @@
 #include <nlopt.h>
 
 static const R_CallMethodDef CallEntries[] = {
-  {"run_testthat_tests", (DL_FUNC) &run_testthat_tests, 1},
   {"NLoptR_Optimize",    (DL_FUNC) &NLoptR_Optimize,    1},
   {NULL, NULL, 0}
 };
@@ -104,4 +103,5 @@ void R_init_nloptr(DllInfo *info) {
     // Register routines to improve lookup from R using .Call interface.
     R_registerRoutines(info, NULL, CallEntries, NULL, NULL);
     R_useDynamicSymbols(info, FALSE);
+    R_forceSymbols(info, TRUE);
 }
